import { WaBucket, WaBucketProps } from "@cre8ivelogix/wa-cdk-lite";
import { Construct } from "constructs";
import { Distribution } from "aws-cdk-lib/aws-cloudfront";
import * as cloudfront from "aws-cdk-lib/aws-cloudfront";
/**
 * X8WebSiteProps can be used to configure several behaviors of the hosted website
 */
export interface X8WebSiteProps {
    /**
     * This property is used to provide the domain name where the website will be hosted
     */
    readonly waDomainName: string;
    /**
     * This property is used to provide the subdomain name where the website will be hosted.
     * @default www
     */
    readonly waSubDomain?: string;
    /**
     * This property is used to provide the site content.
     * @default build
     */
    readonly waPathToContent?: string;
    /**
     * Additional domain names to be included in ssl and redirect traffic to main domain
     */
    readonly waAdditionalDomainNames?: string[];
    /**
     * This property is used to provide custom root object for the cloudfront distribution.
     * @default index.html
     */
    readonly waDefaultRootObject?: string;
    /**
     * This property is used to provide custom error page for the cloudfront distribution. Path must begin with /
     * @default /error.html
     */
    readonly waErrorResponsePagePath?: string;
    /**
     * This property is used to provide any additional bucket policies actions.
     * @default s3:GetObject
     */
    readonly waBucketPolicyActions?: string[];
    /**
     * This property is used to override existing or provide additional properties for bucket configuration.
     */
    readonly waBucketProps?: WaBucketProps;
    /**
     * This property is used to provide existing origin access identity instead of creating a new one.
     */
    readonly waOriginAccessIdentity?: cloudfront.OriginAccessIdentity;
    /**
     * This property is used to disable or enable cloudfront logging.
     * @default false
     */
    readonly waEnableCloudFrontLogging?: boolean;
    /**
     * This property is used to override the cloudfront distribution behavior.
     */
    readonly waCloudFrontDistributionDefaultBehavior?: cloudfront.BehaviorOptions;
}
/**
 * This construct can help build Well Architected infrastructure for website hosting in AWS using S3 Bucket
 * It will create the following Well Architected resources using CRE8IVELOGIX
 * Well Architected CDK Lite as part of the infrastructure
 * 1. A validated public certificate for the website domain
 * 2. An S3 Bucket using Well Architected Bucket construct
 * 3. Creates and attaches the Bucket policies
 * 4. A CloudFront distribution for bucket origin
 * 7. A Route53 record to route traffic to CloudFront Distribution
 * 8. Deploys the website content to the bucket
 *
 * ### Default Alarms
 *
 * ###Examples
 * Default Usage
 * ```ts
 * new X8Website(this, "LogicalId", {
 *      waDomainName: 'cre8ivelogix.com',
 *      waSubdomain: "www",
 *      waPathToContent: './site-content'
 * });
 * ```
 *
 * Custom Configuration
 * ```ts
 * new X8Website(this, "LogicalId", {
 *      waDomainName: 'cre8ivelogix.com',
 *      waSubdomain: "www",
 *      waPathToContent: './site-content',
 *      waAdditionalDomainNames: ['www2.cre8ivelogix.com']
 * });
 * ```
 *
 * ### Compliance
 * It addresses the following compliance requirements
 * * Enable Origin Access Identity for Distributions with S3 Origin
 * * Use CloudFront Content Distribution Network
 * * Enable S3 Block Public Access for S3 Buckets
 * * Enable S3 Bucket Keys
 * * Secure Transport
 * * Server Side Encryption
 */
export declare class X8Website extends Construct {
    /**
     * CloudFront distribution used in this construct
     */
    readonly cdn: Distribution;
    /**
     * Bucket hosting website content
     */
    readonly websiteBucket: WaBucket;
    /**
     * Origin Access Identity
     */
    readonly cloudfrontOAI: cloudfront.OriginAccessIdentity;
    constructor(scope: Construct, name: string, props: X8WebSiteProps);
    static domainNameToPascalCase(domainName: string): string;
    getDistributionDomains(props: X8WebSiteProps): string[];
    getSiteDomain(props: X8WebSiteProps): string;
    getCertificateDomains(props: X8WebSiteProps): string[];
}
